html, body
    {position:relative; height:100%; margin:0; padding:0; color:#333333; background-color:#efefef; }

img
    {border:none;}
a
    {color:#333333; text-decoration:underline;}
a:hover
    {text-decoration:none;}

table
    {border-collapse:collapse;}

td, th
    {vertical-align:top; text-align:left; padding:0.1em 0.4em;}

.clear 
    {clear: both;}

#controlpanel
    {position:absolute; top: 2em; left:0px; width:13em; bottom: 0; overflow: auto;}

    div#actions
        {padding:0; margin:0;}

    div#actions div {
        float: left;
        margin: 3px 2px 3px 2px;
        width: 28px;
        line-height: 26px;
        height: 28px;
        background-color: white;
        border-style: solid;
        border-color: #80c0ff;
        border-width: 1px 1px 1px 1px;
        border-radius: 4px;
        text-align: center;
    }

    div#actions div:hover {
        background-color: #efefef;
    }

    div#actions div img {
        vertical-align: middle;
    }

    #controlpanel ul
        {padding: 0; margin-left: 0; margin-top: 0; list-style: none;}
        #controlpanel ul ul
            { margin-left: 0.7em; }
        #controlpanel ul li
            {clear: both;}
        #controlpanel ul a
            {text-decoration:none; display: block; overflow: auto;}
        #controlpanel ul li span /* workaround for IE6 */
            {cursor: pointer;}
        #controlpanel ul a:hover
            {text-decoration:underline;}
        #controlpanel li.selected
            {font-weight:bold;}
        #controlpanel li.selected li
            {font-weight: normal;}
        #controlpanel li span.name
            {float: left;}
        #controlpanel li img
            {float: left; margin-right: 0.3em; }
        #controlpanel li span.counts
            {float: right;}

    #mailnavigation
        {margin-bottom:1em; padding:0.2em 0.5em;}

    #controlpanel #folder_tree {
        background-color: white;
        border-style: solid;
        border-color: #80c0ff;
        border-width: 1px 1px 1px 0;
        border-bottom-right-radius: 8px;
        -khtml-border-bottom-right-radius: 8px;
        -moz-border-radius-bottomright: 8px;
        -webkit-border-bottom-right-radius: 8px;
        border-top-right-radius: 8px;
        -khtml-border-top-right-radius: 8px;
        -moz-border-radius-topright: 8px;
        -webkit-border-top-right-radius: 8px;
        padding: 0.2em 0.5em;
        margin-left: -0.5em;
        overflow: auto;
    }

    #controlpanel #folder_tree .inbox
        {margin-bottom: 0.5em;}

    #controlpanel #folder_tree .trash,.sent
        {margin-top: 0.5em;}

    #controlpanel #folder_tree a:hover
        {background: #80c0ff;}

    #controlpanel .activeborder {
        position: absolute;
        right: 0;
        top: 0;
        height: 100%;
        width: 3px;
        cursor: w-resize;
        background-color: lightgray;
    }

    #controlpanel #quotas div {
        background-color: white;
        border-style: solid;
        border-color: #80c0ff;
        border-width: 1px 1px 1px 0;
        border-bottom-right-radius: 8px;
        -khtml-border-bottom-right-radius: 8px;
        -moz-border-radius-bottomright: 8px;
        -webkit-border-bottom-right-radius: 8px;
        border-top-right-radius: 8px;
        -khtml-border-top-right-radius: 8px;
        -moz-border-radius-topright: 8px;
        -webkit-border-top-right-radius: 8px;
        padding: 0em 0.5em;
        margin-left: -0.5em;
    }
    
    #controlpanel #quotas div div {
        background-color: #80c0ff;
        margin-left: -0.5em;
    }


#headline
    {position:absolute; top:0px; height:2em; left:0; right:0px; line-height: 2em; background-color:#ffffff; border-left:1px solid #cccccc; border-bottom:1px solid #cccccc; z-index: 99;}
    #headline h1#logo
        {margin: 0 0 0 0.5em; float: left; vertical-align: middle; font-size:110%;}
    #headline a 
        {float: right; margin: 0 0.5em 0 0; vertical-align: middle; text-decoration: none;}
    #headline a:hover
        {text-decoration: underline;}

#content
    {position:absolute; top:2em; bottom: 0px; left:13em; right:0; padding:0; background-color:#ffffff; border-left:1px solid #cccccc; }

    #content #subheadline 
        {height: 1.8em; line-height: 1.8em; background-color: #418bd4; color: white;}

    #content #subheadline *
        {vertical-align: middle;}

    #content #subheadline h1
        {margin: 0 0 0 0.5em; font-size: 120%; float: left;}

    #content #container {
        position: absolute;
        top: 1.9em;
        left: 0;
        right: 0;
        margin: 1em;

        border-style: solid;
        border-color: #80c0ff;
        border-width: 1px 1px 1px 1px;

        border-bottom-right-radius: 8px;
        -khtml-border-bottom-right-radius: 8px;
        -moz-border-radius-bottomright: 8px;
        -webkit-border-bottom-right-radius: 8px;
        
        border-top-right-radius: 8px;
        -khtml-border-top-right-radius: 8px;
        -moz-border-radius-topright: 8px;
        -webkit-border-top-right-radius: 8px;

        border-top-left-radius: 8px;
        -khtml-border-top-left-radius: 8px;
        -moz-border-radius-topleft: 8px;
        -webkit-border-top-left-radius: 8px;

        border-bottom-left-radius: 8px;
        -khtml-border-bottom-left-radius: 8px;
        -moz-border-radius-bottomleft: 8px;
        -webkit-border-bottom-left-radius: 8px;

        overflow: auto;
    }

    #content #manage_folder_tree {
        padding: 0;
        margin: 0;
        list-style: none;
    }

    #content #manage_folder_tree ul {
        list-style: none;
    }

#compose form, #login form { padding: 0 0.5em; }

#loading_message
    {display: none;}

@media print {
    *   { position: static !important; overflow: visible !important; float: none !important; }
    #controlpanel, #quicksearch, .message_actions, th.actions, td.actions
        { display: none; }
    body, html, #content
        { height: auto; }
    #content
        { border: none; }
    a   { text-decoration: none; }
}


input { border: 1px solid black; }
textarea { border: 1px solid black; }
button { border: 1px solid black; }

/* dialog */
#dialog {
    display: none;
    width: 360px;
    height: 140px;
    border: 1px solid black;
    background-color: white;
    padding: 0px;
    margin-top: 4em;
    margin-left: auto;
    margin-right: auto;
    position: absolute;
    z-index: 99;
    left: 0;
    right: 0;
}

#dialog_title {
    width: 360px;
    height: 2.0em;
    line-height: 2.0em;
    margin: 0px;
    padding: 0px;
    background-color: #E9E9E9;
    font-weight: bold;
}

#dialog_title_text {
    padding: 0 0 0 0.5em;
    margin: 0;
    font-weight: bold;
    vertical-align: middle;
    text-shadow: 1px 1px 1px #ffffff;
    filter: dropshadow(color=#ffffff, offx=1, offy=1);
}

#dialog_text {
    width: 360px;
    color: black;
    margin: 1em 1em 0 1em;
    position: absolute;
}

#dialog_buttons {
    width:360px;
    margin-left: auto;
    margin-right: auto;
    margin-top: 65px;
    text-align: center;
    position: absolute;
}


.dialog_button, .dialog_button:visited {
    display: inline-block;
    cursor: pointer;

    color: white;
    font-size: 12px; 
    font-weight: bold; 
    line-height: 1; 

    position: relative;
    width: 50px;
    padding-top: 6px;
    padding-right: 10px;
    padding-bottom: 5px;
    padding-left: 10px;

    margin: 0 1em 0 1em;

    -moz-border-radius: 2px;
    -webkit-border-radius: 2px;
    -moz-box-shadow: 0 1px 2px rgba(0,0,0,0.25);
    -webkit-box-shadow: 0 1px 2px rgba(0,0,0,0.25);
    border-bottom: 1px solid #B63440;

    text-decoration: none;
    text-shadow: 1px 1px 1px  rgba(0,0,0,0.45);
    filter: dropshadow(color= rgba(0,0,0,0.45), offx=1, offy=1);
}

.dialog_button span {
    float: right;
    text-align: right;
    width: 40px;
}

#dialog_buttons .left
    {float: left}

#dialog_buttons .right
    {float: right}

.dialog_button:active
    {top: 1px; left: 1px;}

#dialog .green, .dialog .green:visited
    {background-color: #72B930; border:1px solid #5D8C22;}

#dialog .green:hover
    {background-color:#7DCA34;}

//add checkmark / X symbol
#dialog .green:before
    {content: '\2713';}

#dialog .grey:before
    {content: '\2713';}

#dialog .red:before
    {content: '\2717';}

#dialog .grey, .dialog .green:visited
    {background-color: #efefef; border:1px solid #8E8E8E; color: #424242; }

#dialog .grey:hover
    {background-color:#B8B8B8;}

#dialog .red, .dialog .red:visited
    {background-color:#E64444; border:1px solid #B63440;}

#dialog .red:hover
    {background-color:#FF4B5A;}

#dialog_progressbar {
    display: none;
    text-align: center;
    width: 360px;
    position: absolute;
    margin-top: 1em;
}

#dialog_progressbar .wrapper {
    width: 340px;
    border: 1px solid black;
    height: 20px;
    padding: 0px;
    margin-top: 0.5em;
    margin-left: auto;
    margin-right: auto;
    background-color: white;

    border-radius: 4px;
    -moz-border-radius: 4px;
    -webkit-border-radius: 4px;

    box-shadow: 0 1px 2px rgba(0,0,0,0.25);
    -moz-box-shadow: 0 1px 2px rgba(0,0,0,0.25);
    -webkit-box-shadow: 0 1px 2px rgba(0,0,0,0.25);
}

#dialog_progressbar .bar {
    padding: 0px;
    height: 20px;
    width: 0%;
    background-color: #96CA65;
    overflow: hidden;
}

#dialog_progressbar .detail {
   padding: 0 0.5em 0 0;
   margin: 0;
   float: right;
   color: black;
   overflow: hidden;
   line-height: 20px;
   vertical-align: middle;
   font-size: 11px;
}

#lock_overlay {
    position: fixed;
    width: 100%;
    height: 100%;
    opacity: 0.7;
    filter: alpha(opacity = 70);
    background: black;
    z-index: 90;
    top: 0;
    left: 0;
    display: none;
}
