body { padding: 0; background: #747573; font-family: Verdana; }
#title { position: absolute; top: 50%; left: 50%; width: 400px; margin-left: -200px; margin-top: -120px; height: 100px; vertical-align: bottom; color: #fff; font-size: 57px;}
#login { position: absolute; top: 50%; left: 0; right: 0; margin-top: -60px; height: 120px; border-top: 1px solid #fff; border-bottom: 1px solid #fff; background: #999; }
#login form { position: absolute; top: 50%; left: 50%; margin-left: -200px; width: 400px; height: 65px; margin-top: -32px; }
#login label { display: block; clear: left; }
#login label span { float: left; width: 8em; }
#login input { border: 1px solid black; width: 19em; }
#login button { border: 1px solid black; }
