#message_view {
    margin: 0.5;
    padding: 0.5;
}

#message_view h1 {
    margin: 0;
    padding: 0.1em 0.5em;
    border-bottom: 1px solid black;
    background-color: #418bd4;
    color: white;
    font-size: 100%;
}

.message_actions {
    margin: 0.1em 0;
    padding: 0.1em 0.5em;
    border-bottom: 1px solid black;
    overflow: auto;
}

.message_actions a {
    text-decoration: none;
    border: 1px solid #efefef;
}

.message_actions img {
    vertical-align: bottom;
}

.message_actions a:hover {
    border-color: #418bd4;
}

.message_main_actions {
    float: left;
}

.message_view_head {
    margin: 0em 0.5em 0em 0.5em;
    border: 1px solid black;
    background-color: #efefef;
}

a.load_subpart {
    text-decoration: none;
    color: white;
}

.message_header {
    overflow: auto;
    margin: 0px;
    padding: 0px;
}

.message_header table {
    margin: 0;
}

.message_detail_actions {
    font-size: 75%;
    float: right;
    color: gray;
}

.message_header tr th {
    font-weight: bold;
}

.message_header tr td {
}

.body_part, pre.all_headers {
    clear: both;
}

.image img {
    width: 100% !important;
}

.message_body {
    margin: 0 0.5em 0.5em 0.5em;
    border-color: black;
    border-width: 0px 1px 1px 1px;
    border-style: solid;
}

.message_rfc822 {
    padding-top: 0.5em;
}

.renderable {
    margin: 0px;
    padding: 3px;
}

.html_message iframe {
    width: 100%;
    height: 600px; /* this will get replace by resize_iframe() javascript if JS is enabled */
    border: 0px;
    margin: 0px;
    padding: 0px;
}

.forwarded {
    margin: 0px;
    padding: 1px;
    overflow: auto;
}

.attachment {
    border: 1px grey solid;
    background-color: white;
    border-radius: 8px;
    -khtml-border-radius: 8px;
    -moz-border-radius: 8px;
    float: left;
    padding: 0.5em;
    margin: 0.3em;
    text-align: center;
}

.attachment a {
    text-decoration: none;
}

.attachment a span {
    margin: 0px;
    padding: 0px;
    font-size: 75%;
}

div.calendar table {
    border: 1px black solid;
    border-collapse: collapse;
}

div.calendar table th {
    font-weight: bold;
}

div.calendar table tr {
    border: 1px black solid;
}

div.calendar .heading {
    background-color: #418bd4;
    color: white;
}

.monospace {
    font-family: monospace;
}

.rtl {
    direction: RTL;
    unicode-bidi: embed;
}

div.external_content_warning {
    position: relative;
    left: 2px;
    right: 2px;
    margin: 4px;
    padding: 2px 4px 2px 4px;
    border: 1px solid red;
    background-color: yellow;
}

div.external_content_warning span {
    font-weight: bold;
}

div.external_content_warning a {
    position: absolute;
    top: 0px;
    bottom: 0px;
    right: 0px;
    padding: 2px 4px 2px 4px;
    background-color: white;
    font-weight: bold;
    text-decoration: none;
}

div.external_content_warning a:hover {
    text-decoration: underline;
}
