fieldset {
    border-top: 1px solid;
    border-bottom: 0;
    border-left: 0;
    border-right: 0;
}

label {
    display: block;
    clear: left;
    text-align: left;
}

label span {
    float: left;
    text-align: left;
    width: 14%;
}

input {
    width: 30%;
}

label.text span {
    float: none;
    display: block;
}

textarea {
    width: 100%;
    height: 30em;
}


