html, body {
    overflow-y: hidden;
}

.message_list {
    width: 100%;
    table-layout: fixed;
}

.message_list a {
    text-decoration: none;
    display: block;
}

.message_list a:hover {
    text-decoration: underline;
}

.message_list tr.odd {
    background-color: #f8f7f6;
}

.message_list th.icons {
    width: 52px;
}

.message_list th.from {
    width: 25%;
}

.message_list th.date {
    width: 9em;
}

.message_list.date th.date {
    width: 4em;
}

.message_list th.actions {
    width: 15px;
}

.messages_list th {
    vertical-align: middle;
    line-height: 1.4em;
}

.message_list tbody tr td {
    border-style: solid;
    border-color: lightgrey;
    border-width: 0px 0px 1px 0px;
    font-size: 0.8em;
    line-height: 1.4em;
    vertical-align: middle;
    overflow: hidden;
}

.message_list tbody tr.group_head {
    background-color: #c5c5c4;
}

.message_list tr th {
    border-style: solid;
    border-color: lightgrey #bebebe lightgrey #efefef;
    background-color: #efefef;
    border-width: 1px 1px 2px 0px;
}


.message_list tr {
    font-weight: bold;
}

.message_list tr.seen {
    font-weight: normal !important;
}

.message_list tr.recent {
    font-weight: bold;
}

.message_list tr.answered * {
    color: blue;
}

.message_list tr.forwarded * {
    color: green;
}

.message_list tr.deleted * {
    color: red;
    text-decoration: line-through;
}

#message_list tbody tr.active {
    background-color: #80c0ff;
}

ul#folder_tree a.hover {
    color: white;
    background-color: green;
}

.message_list img {
    position: relative;
    vertical-align: middle;
}

.message_list td.sender {
    white-space: nowrap;
}

.message_list th.sorted a {
    background: url(../../images/sort_up.png) no-repeat right center;
    padding-right: 9px;
}

.message_list th.reverse a {
    background-image: url(../../images/sort_down.png);
}

#messages_pane {
    position: absolute;
    top: 1.9em;
    bottom: 30%;
    left: 0;
    width: 100%;
    overflow: auto;
}

#content.message_display #messages_pane {
}

#messages_pane tr.selected {
    background-color: lightblue;
}

#message_view {
    position: absolute;
    top: 70%;
    bottom: 0;
    left: 0;
    right: 0;
    overflow: auto;
    padding: 0 0.5em;
    margin-top: 4px;
}

#message_divider {
    position: absolute;
    left: 0;
    top: 70%;
    width: 100%;
    height: 4px;
    cursor: n-resize;
    background-color: lightgray;
}

#message_view .move_message {
    display: none;
}

.dragger {
    position: absolute;

    margin: 0;
    padding: 0;
    list-style: none;

    background-color: white;
    border: 1px solid black;
    color: black;
    opacity: 0.5;
    -moz-opacity: 0.5;
}

.dragger li {
    margin: 0;
    padding: 0;
}

#quicksearch {
    float: right;
}

#quicksearch button {
    margin-right: 0.5em;
}

@media print {
    #content.message_display #folder_headline, #content.message_display #messages_pane, #help_message {
        display: none;
    }
    #messages_pane {
        border: none;
    }
}
